@@ -37,8 +37,9 @@ SNAP_TIME = config.getint('DEFAULT', 'MINUTES_FOR_SNAP') * 60
 
 
 @task
-def create_instance(region_name='us-east-1', zone_name=None, key_pair=None,
-                    security_groups='', architecture=None, user_data=None):
+def create_instance(
+        region_name='us-east-1', zone_name=None, key_pair=None,
+        security_groups='', architecture=None, user_data=None, inst_type=None):
     """
     Create AWS EC2 instance.
 
@@ -55,7 +56,10 @@ def create_instance(region_name='us-east-1', zone_name=None, key_pair=None,
         list of AWS Security Groups names formatted as string separated
         with semicolon ';';
     architecture
-        "i386" or "x86_64".
+        "i386" or "x86_64";
+    inst_type
+        by default will be fetched from AMI description or used
+        't1.micro' if not mentioned in the description.
     """
     conn = get_region_conn(region_name)
 
@@ -90,7 +94,8 @@ def create_instance(region_name='us-east-1', zone_name=None, key_pair=None,
     image = conn.get_all_images(filters=filters)[0]
     return launch_instance_from_ami(
         region_name, image.id, security_groups=security_groups,
-        key_pair=key_pair, zone_name=zone_name, user_data=user_data)
+        key_pair=key_pair, zone_name=zone_name, user_data=user_data,
+        inst_type=inst_type)
 
 
 @contextmanager
